Method: ActionView::Helpers::AssetTagHelper#javascript_path
- Defined in:
- lib/action_view/helpers/asset_tag_helper.rb
#javascript_path(source) ⇒ Object Also known as: path_to_javascript
Computes the path to a javascript asset in the public javascripts directory. If the source filename has no extension, .js will be appended. Full paths from the document root will be passed through. Used internally by javascript_include_tag to build the script path.
Examples
javascript_path "xmlhr" # => /javascripts/xmlhr.js
javascript_path "dir/xmlhr.js" # => /javascripts/dir/xmlhr.js
javascript_path "/dir/xmlhr" # => /dir/xmlhr.js
javascript_path "http://www.railsapplication.com/js/xmlhr" # => http://www.railsapplication.com/js/xmlhr.js
javascript_path "http://www.railsapplication.com/js/xmlhr.js" # => http://www.railsapplication.com/js/xmlhr.js
184 185 186 |
# File 'lib/action_view/helpers/asset_tag_helper.rb', line 184 def javascript_path(source) compute_public_path(source, 'javascripts', 'js') end |